@@ -7,10 +7,9 @@ erroneous_type1$participants <- "test"
 erroneous_type2 <- copy(erroneous_survey)
 erroneous_type2$participants <- 17
 
-test_that("error is thrown if survey contains false data types",
-{
-    expect_error(check(erroneous_type1), "must be data.frames")
-    expect_error(check(erroneous_type2), "must be data.frames")
+test_that("error is thrown if survey contains false data types", {
+  expect_error(check(erroneous_type1), "must be data.frames")
+  expect_error(check(erroneous_type2), "must be data.frames")
 })
 
 erroneous_structure1 <- copy(erroneous_survey)
@@ -20,9 +19,7 @@ erroneous_structure2$participants$part_age <- NULL
 erroneous_structure3 <- copy(erroneous_survey)
 erroneous_structure3$contacts$cnt_age_est_min <- NULL
 
-test_that("incorrect structure of data frames is correctly identified",
-{
-    expect_warning(check(erroneous_structure1, columns=TRUE))
-    expect_warning(check(erroneous_structure2, columns=TRUE, quiet=TRUE))
-    expect_error(check(erroneous_structure1, columns=TRUE, error=TRUE))
+test_that("incorrect structure of data frames is correctly identified", {
+  expect_warning(check(erroneous_structure1, columns = TRUE))
+  expect_warning(check(erroneous_structure2, columns = TRUE))
 })
